@@ -12,7 +12,7 @@
 #define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
 #define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
 #define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
-#define PCW_APP_VERSION "0.9.2"
+#define PCW_APP_VERSION "0.9.3"
 
 namespace Ui {
     class SettingsDialog;
@@ -30,6 +30,9 @@ public:
     ~SettingsDialog();
     void checkVersion();
 
+protected:
+    void showEvent(QShowEvent* event);
+
 private:
     Ui::SettingsDialog *ui;
     void openBrowser(QString url);
